@@ -3,5 +3,5 @@ from django.utils.translation import gettext_lazy as _
 
 
 class JauthConfig(AppConfig):
-    name = 'jauth'
-    verbose_name = _('OAuth2 Authentication')
+    name = "jauth"
+    verbose_name = _("OAuth2 Authentication")
